summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/rubycodegenerator.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenerators/rubycodegenerator.cpp')
-rw-r--r--umbrello/umbrello/codegenerators/rubycodegenerator.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/umbrello/umbrello/codegenerators/rubycodegenerator.cpp b/umbrello/umbrello/codegenerators/rubycodegenerator.cpp
index 65b2af15..0cd9176f 100644
--- a/umbrello/umbrello/codegenerators/rubycodegenerator.cpp
+++ b/umbrello/umbrello/codegenerators/rubycodegenerator.cpp
@@ -59,10 +59,10 @@ Uml::Programming_Language RubyCodeGenerator::getLanguage() {
}
// In the Java version, we make the ANT build file also available.
-CodeViewerDialog * RubyCodeGenerator::getCodeViewerDialog ( TQWidget* tqparent, CodeDocument *doc,
+CodeViewerDialog * RubyCodeGenerator::getCodeViewerDialog ( TQWidget* parent, CodeDocument *doc,
Settings::CodeViewerState state)
{
- CodeViewerDialog *dialog = new CodeViewerDialog(tqparent, doc, state);
+ CodeViewerDialog *dialog = new CodeViewerDialog(parent, doc, state);
return dialog;
}
@@ -127,7 +127,7 @@ CodeDocument * RubyCodeGenerator::newClassifierCodeDocument ( UMLClassifier * c)
/* These initializations are done in CodeGenFactory::createObject()
void RubyCodeGenerator::initFields() {
UMLApp::app()->setPolicyExt ( new RubyCodeGenerationPolicy(UMLApp::app()->getConfig()) );
// load Classifier documents from tqparent document
initFromParentDocument();
}
*/
@@ -127,7 +127,7 @@ CodeDocument * RubyCodeGenerator::newClassifierCodeDocument ( UMLClassifier * c)
void RubyCodeGenerator::initFields() {
UMLApp::app()->setPolicyExt ( new RubyCodeGenerationPolicy(UMLApp::app()->getConfig()) );
- // load Classifier documents from tqparent document
+ // load Classifier documents from parent document
initFromParentDocument();
}